==> nextcloud-24.0.10.tgz: nextcloud/apps/viewer/l10n/lv.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Skatītājs",
    "Simple file viewer with slideshow for media" : "Vienkāršs datņu skatītājs ar slaidrādi multividei",
    "Error loading {name}" : "Kļūda ielādējot {name}",
    "Edit" : "Rediģēt",
    "Open sidebar" : "Atvērt sānjoslu",
    "Download" : "Lejupielādēt",
    "Delete" : "Dzēst",
    "View" : "Skats",
    "Name" : "Vārds",
    "Save" : "Saglabāt",
    "Save as" : "Saglabāt kā",
    "Back" : "Atpakaļ",
    "Reset" : "Atiestatīt",
    "Cancel" : "Atcelt",
    "Continue" : "Turpināt",
    "Undo" : "Atsaukt",
    "Redo" : "Atcelt atsaukšanu",
    "Original" : "Oriģināls",
    "Custom" : "Pielāgots",
    "Value" : "Vērtība",
    "Image" : "Attēli",
    "Text" : "Teksts",
    "Size" : "Izmērs",
    "Save image as" : "Saglabāt attēlu kā",
    "Quality" : "Kvalitāte",
    "Saved image size (width x height)" : "Saglabātā attēla izmērs (platums x augstums)",
    "Actual size (100%)" : "Faktiskais izmērs (100%)",
    "Fit size" : "Atbilst izmēram",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Rādiet savus jaunākos brīvdienu fotoattēlus un videoklipus kā filmās, rādiet savu jaunāko romānu tieši no Nextcloud, izvēlieties savas kolekcijas labākos GIF, pateicoties tiešajam izlases datņu priekšskatījumam un daudziem citiem!"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/viewer/l10n/lv.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Skatītājs",
    "Simple file viewer with slideshow for media" : "Vienkāršs datņu skatītājs ar slaidrādi multividei",
    "Error loading {name}" : "Kļūda ielādējot {name}",
    "Your browser does not support videos." : "Pārlūks nenodrošina video",
    "Edit" : "Labot",
    "Open sidebar" : "Atvērt sānjoslu",
    "Download" : "Lejupielādēt",
    "Delete" : "Dzēst",
    "View" : "Skats",
    "Name" : "Vārds",
    "Save" : "Saglabāt",
    "Save as" : "Saglabāt kā",
    "Back" : "Atpakaļ",
    "Loading …" : "Ielādē…",
    "Reset" : "Atiestatīt",
    "Cancel" : "Atcelt",
    "Apply" : "Apstiprināt",
    "Warning" : "Brīdinājums",
    "Confirm" : "Apstiprināt",
    "Undo" : "Atsaukt",
    "Redo" : "Atcelt atsaukšanu",
    "Filters" : "Filtri",
    "Watermark" : "Ūdenszīme",
    "are not images" : "nav attēli",
    "is not an image" : "nav attēls",
    "Original" : "Oriģināls",
    "Custom" : "Pielāgots",
    "Landscape" : "Ainava",
    "Portrait" : "Portrets",
    "Value" : "Vērtība",
    "Image" : "Attēli",
    "Text" : "Teksts",
    "Size" : "Izmērs",
    "Save image as" : "Saglabāt attēlu kā",
    "Name is required." : "Vārds ir nepieciešams.",
    "Quality" : "Kvalitāte",
    "Saved image size (width x height)" : "Saglabātā attēla izmērs (platums x augstums)",
    "Actual size (100%)" : "Faktiskais izmērs (100%)",
    "Fit size" : "Atbilst izmēram",
    "Menu" : "Izvēlne"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
